@@ -1,12 +1,11 @@
 /* global.c: global command routines for the ed line editor */
 /*  GNU ed - The GNU line editor.
     Copyright (C) 1993, 1994 Andrew Moore, Talke Studio
-    Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014
-    Free Software Foundation, Inc.
+    Copyright (C) 2006-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
+    the Free Software Foundation, either version 2 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -60,7 +59,8 @@ bool set_active_node( const line_t * const lp )
   if( !resize_line_buffer( &active_list, &active_size,
                            ( active_len + 1 ) * sizeof (line_t **) ) )
     {
-    show_strerror( 0, errno ); set_error_msg( "Memory exhausted" );
+    show_strerror( 0, errno );
+    set_error_msg( "Memory exhausted" );
     enable_interrupts();
     return false;
     }
