@@ -1,10 +1,9 @@
 /*  GNU ed - The GNU line editor.
-    Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014
-    Free Software Foundation, Inc.
+    Copyright (C) 2006-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
+    the Free Software Foundation, either version 2 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -43,13 +42,13 @@
 #include "ed.h"
 
 
-static const char * const Program_name = "GNU Ed";
 static const char * const program_name = "ed";
-static const char * const program_year = "2014";
+static const char * const program_year = "2019";
 static const char * invocation_name = 0;
 
 static bool restricted_ = false;	/* if set, run in restricted mode */
-static bool scripted_ = false;		/* if set, suppress diagnostics */
+static bool scripted_ = false;		/* if set, suppress diagnostics,
+					   byte counts and '!' prompt */
 static bool traditional_ = false;	/* if set, be backwards compatible */
 
 
@@ -60,8 +59,14 @@ bool traditional( void ) { return traditional_; }
 
 static void show_help( void )
   {
-  printf( "%s - The GNU line editor.\n", Program_name );
-  printf( "\nUsage: %s [options] [file]\n", invocation_name );
+  printf( "GNU ed is a line-oriented text editor. It is used to create, display,\n"
+          "modify and otherwise manipulate text files, both interactively and via\n"
+          "shell scripts. A restricted version of ed, red, can only edit files in\n"
+          "the current directory and cannot execute shell commands. Ed is the\n"
+          "'standard' text editor in the sense that it is the original editor for\n"
+          "Unix, and thus widely available. For most purposes, however, it is\n"
+          "superseded by full-screen editors such as GNU Emacs or GNU Moe.\n"
+          "\nUsage: %s [options] [file]\n", invocation_name );
   printf( "\nOptions:\n"
           "  -h, --help                 display this help and exit\n"
           "  -V, --version              output version information and exit\n"
@@ -69,8 +74,8 @@ static void show_help( void )
           "  -l, --loose-exit-status    exit with 0 status even if a command fails\n"
           "  -p, --prompt=STRING        use STRING as an interactive prompt\n"
           "  -r, --restricted           run in restricted mode\n"
-          "  -s, --quiet, --silent      suppress diagnostics\n"
-          "  -v, --verbose              be verbose\n"
+          "  -s, --quiet, --silent      suppress diagnostics, byte counts and '!' prompt\n"
+          "  -v, --verbose              be verbose; equivalent to the 'H' command\n"
           "Start edit by reading in 'file' if given.\n"
           "If 'file' begins with a '!', read output of shell command.\n"
           "\nExit status: 0 for a normal exit, 1 for environmental problems (file\n"
@@ -85,9 +90,9 @@ static void show_help( void )
 
 static void show_version( void )
   {
-  printf( "%s %s\n", Program_name, PROGVERSION );
+  printf( "GNU %s %s\n", program_name, PROGVERSION );
   printf( "Copyright (C) 1994 Andrew L. Moore.\n"
-          "Copyright (C) %s Free Software Foundation, Inc.\n", program_year );
+          "Copyright (C) %s Antonio Diaz Diaz.\n", program_year );
   printf( "License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n"
           "This is free software: you are free to change and redistribute it.\n"
           "There is NO WARRANTY, to the extent permitted by law.\n" );
@@ -98,8 +103,7 @@ void show_strerror( const char * const filename, const int errcode )
   {
   if( !scripted_ )
     {
-    if( filename && filename[0] != 0 )
-      fprintf( stderr, "%s: ", filename );
+    if( filename && filename[0] ) fprintf( stderr, "%s: ", filename );
     fprintf( stderr, "%s\n", strerror( errcode ) );
     }
   }
@@ -108,11 +112,9 @@ void show_strerror( const char * const filename, const int errcode )
 static void show_error( const char * const msg, const int errcode, const bool help )
   {
   if( msg && msg[0] )
-    {
-    fprintf( stderr, "%s: %s", program_name, msg );
-    if( errcode > 0 ) fprintf( stderr, ": %s", strerror( errcode ) );
-    fprintf( stderr, "\n" );
-    }
+    fprintf( stderr, "%s: %s%s%s\n", program_name, msg,
+             ( errcode > 0 ) ? ": " : "",
+             ( errcode > 0 ) ? strerror( errcode ) : "" );
   if( help )
     fprintf( stderr, "Try '%s --help' for more information.\n",
              invocation_name );
@@ -130,7 +132,7 @@ bool is_regular_file( const int fd )
 bool may_access_filename( const char * const name )
   {
   if( restricted_ &&
-      ( *name == '!' || !strcmp( name, ".." ) || strchr( name, '/' ) ) )
+      ( *name == '!' || strcmp( name, ".." ) == 0 || strchr( name, '/' ) ) )
     {
     set_error_msg( "Shell access restricted" );
     return false;
@@ -183,13 +185,14 @@ int main( const int argc, const char * const argv[] )
                 return 3;
       }
     } /* end process options */
+
   setlocale( LC_ALL, "" );
   if( !init_buffers() ) return 1;
 
   while( argind < ap_arguments( &parser ) )
     {
     const char * const arg = ap_argument( &parser, argind );
-    if( !strcmp( arg, "-" ) ) { scripted_ = true; ++argind; continue; }
+    if( strcmp( arg, "-" ) == 0 ) { scripted_ = true; ++argind; continue; }
     if( may_access_filename( arg ) )
       {
       if( read_file( arg, 0 ) < 0 && is_regular_file( 0 ) )
@@ -198,7 +201,7 @@ int main( const int argc, const char * const argv[] )
       }
     else
       {
-      fputs( "?\n", stderr );
+      fputs( "?\n", stdout );
       if( arg[0] ) set_error_msg( "Invalid filename" );
       if( is_regular_file( 0 ) ) return 2;
       }
